# Perper

Stream-based, horizontally scalable framework for asynchronous data
processing, built on top of [Apache Ignite](https://ignite.apache.org/)
and [Azure Functions Host](https://github.com/Azure/azure-functions-host).
